/* Combustion Analysis Tool (CAT)
   www.catool.org
   
   Filename: matfile.h

   Purpose:  Provide common programming interface for processing acquired engine data
  
   Author:   Ben Brown
   Version:  1.2
   Date:     19.10.2015

   Revision: GPL Release

   Copyright (C) Xarin Limited, 2000-2023

      This program is free software: you can redistribute it and/or modify
      it under the terms of version 2 of the GNU General Public License as
      published by the Free Software Foundation.

      This program is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
      GNU General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __MATFILE_H__
#define __MATFILE_H__

#include <stdio.h>

#define miINT8			1
#define miUINT8			2
#define miINT16			3
#define miUINT16		4
#define miINT32			5
#define miUINT32		6
#define miSINGLE		7
#define miDOUBLE		9
#define miINT64			12
#define miUINT64		13
#define miMATRIX		14
#define miCOMPRESSED	15
#define miUTF8			16
#define miUTF16			17
#define miUTF32			18

#define mxCELL_CLASS	1
#define mxSTRUCT_CLASS	2
#define mxOBJECT_CLASS	3
#define mxCHAR_CLASS	4
#define mxSPARSE_CLASS	5
#define mxDOUBLE_CLASS	6
#define mxSINGLE_CLASS	7
#define mxINT8_CLASS	8
#define mxUINT8_CLASS	9
#define mxINT16_CLASS	10
#define mxUINT16_CLASS	11
#define mxINT32_CLASS	12
#define mxUINT32_CLASS	13
#define mxINT64_CLASS	14
#define mxUINT64_CLASS	15

#define mfNONE          0x0000
#define mfLOGICAL       0x0200
#define mfGLOBAL        0x0400
#define mfCOMPLEX       0x0800

unsigned int sizeof_datatype(const unsigned int datatype);
size_t ascii_to_utf16(const char* ascii_in, char** utf16_out, const size_t maximum_length);
void validate_variable_name(char* var_name);
void matlab_file_open(FILE* file_handle);
void matlab_file_close(FILE* file_handle);
void matlab_file_write(FILE* file_handle, const unsigned int data_type, const void* data, const unsigned int data_size);
void matlab_file_write_numeric_array(FILE* file_handle, const unsigned int data_type, const bool global, const bool logical, const char* array_name, const unsigned int number_of_array_dimensions, const int* dimensions_data, const void* real_data, const void* imaginary_data);
void matlab_file_write_channel(FILE* file_handle, const FileData* file, const unsigned int number_of_cycles, ChannelData* channel_data);
bool save_matlab_file(FileData* file, const char* filename, Analysis* analysis, const unsigned int ifile_output);
void generate_matlab_channelnames(FileData* file,Analysis* analysis);
void matlab_file_write_double_numeric_array(FILE* file_handle,double value);
void matlab_file_write_uint8_numeric_array(FILE* file_handle,unsigned int value);
void matlab_file_write_string_numeric_array(FILE* file_handle,char* string,int max_length);

#endif
